Changelog
=========

`1.0a2`_
--------

Bugfixes
~~~~~~~~

* Handle PhoneNumberParseErrors gracefully.


`1.0a1`_
--------

New features
~~~~~~~~~~~~

* Deactivate persons that are set to inactive in SchILD

Minor changes
~~~~~~~~~~~~~

* Use bootstrap buttons everywhere
* Show number of created and deactivated persons after import


_`1.0a1`: https://edugit.org/Teckids/AlekSIS/AlekSIS-App-SchILD-NRW/-/tags/1.0a1
_`1.0a2`: https://edugit.org/Teckids/AlekSIS/AlekSIS-App-SchILD-NRW/-/tags/1.0a2
